0.1.4 (released 2022-10-04)
---------------------------

- Bugfix: don't attempt to patch pkg_resources

0.1.3 (released 2018-10-10)
---------------------------

- Fix exception when used with dateutil
- Add support for Python 3.7
- Drop support for Python 2.6

Version 0.1.2
-------------

- Add support for freezing datetime.utcnow()

Version 0.1.1
-------------

- Fix for ImportErrors when used with six

Version 0.1
------------

- Initial release
